#!/usr/bin/python
# Server process that consumes sensor readings and transmitts them to the core IoT engine via MQTTF
#
import os
import time

VERSION = "2.0.0"
SECSINDAY = 86400

def joke():
	return ("hahahahah")

def main():
	print joke()


if __name__ == '__main__':
    main()
